"""
default config module
could write config.py to override all the bot behavior
"""
__name__ = 'defaultConfig'
__package__ = 'ringcentral_bot_framework.core'

def botJoinPrivateChatAction(bot, groupId, user):
  """
  bot join private chat event handler
  bot could send some welcome message or help, or something else
  """
  bot.sendMessage(
    groupId,
    {
      'text': f'Hello, I am a chatbot. Please reply "![:Person]({bot.id})" if you want to talk to me.'
    }
  )

def botGotPostAddAction(
  bot,
  groupId,
  creatorId,
  user,
  text
):
  """
  bot got group chat message: text
  bot could send some response
  """
  if f'![:Person]({bot.id})' in text:
    bot.sendMessage(
      groupId,
      {
        'text': f'![:Person]({creatorId}), Hello, you just posted "{text}"'
      }
    )

def botAuthAction(bot):
  '''
  After bot auth success,
  can do some bot actions
  default: do nothing
  '''
  return

def userAuthSuccessAction(bot, groupId, userId):
  """
  user auth bot app to access user data success,
  bot would do something
  default: send login success message to chatgroup
  if you only have bot app, it is not needed
  """
  bot.sendMessage({
    'text': f'![:Person]({userId}), you have successfully authorized me to access your RingCentral data!'
  })

def userAddGroupInfoAction(bot, user, groupId):
  """
  user add group and bot connect info,
  bot or user could do something about it,
  default: do nothing
  if you only have bot app, it is not needed
  """
  return

def userAuthSuccessHtml(user, conf):
  """
  user auth success, would see this html from browser
  if you only have bot app, it is not needed
  """
  return '<div style="text-align: center;font-size: 20px;border: 5px solid #08c;padding: 30px;">You have authorized the bot to access your RingCentral data! Please close this page and get back to Glip</div>'

def userEventAction(
  user,
  eventType,
  event,
  getBot
):
  """
  bot got subscribed user event,
  do something about it
  default: post to chatgroup about the event
  if you only have bot app, it is not needed
  """
  groups = user.groups
  keys = groups.keys()
  for groupId in keys:
    botId = groups[groupId]
    bot = getBot(botId)
    if bot != False and eventType != 'PostAdded':
      bot.sendMessage(groupId, {
        'text': f'![:Person]({user.id}), got event "{eventType}"'
      })

def botFilters():
  '''
  customize bot filters to subscribe
  '''
  return [
    '/restapi/v1.0/glip/posts',
    '/restapi/v1.0/glip/groups'
  ]

def userFilters():
  '''
  customize user filters to subscribe
  '''
  return [
    '/restapi/v1.0/account/~/extension/~/message-store'
  ]